@@ -25,7 +25,7 @@ int M_emgroup(double **x,int n,int p,int nclass,double *pi,double **Mu,
     meandispersion(x,n,p,Mu[0],LTSigma[0]);
 */
     meandispersion_MLE(x,n,p,Mu[0],LTSigma[0]);
-    like=-0.5*n*p-0.5*n*log(determinant(LTSigma[0],p))-0.5*n*p*log(2*PI);
+    like=-0.5*n*p-0.5*n*log(determinant(LTSigma[0],p))-0.5*n*p*log(2*M_PI);
   }
   else {
     if(!starts_via_svd(n,p,Mu,x,nclass,nc,pi,class,LTSigma,alpha,1))      {
